@@ -88,9 +88,9 @@ def set_nthreads(nthreads):
     2
 
     """
-    if nthreads > _ext.BLOSC_MAX_THREADS:
+    if nthreads > blosc.MAX_THREADS:
         raise ValueError("the number of threads cannot be larger than %d" %
-                         _ext.BLOSC_MAX_THREADS)
+                         blosc.MAX_THREADS)
 
     return _ext.set_nthreads(nthreads)
 
@@ -115,6 +115,7 @@ def set_blocksize(blocksize):
 
     _ext.set_blocksize(blocksize)
 
+
 def compressor_list():
     """
     compressor_list()
@@ -249,9 +250,9 @@ def _check_cname(cname):
 
 
 def _check_typesize(typesize):
-    if not 1 <= typesize <= _ext.BLOSC_MAX_TYPESIZE:
+    if not 1 <= typesize <= blosc.MAX_TYPESIZE:
         raise ValueError("typesize can only be in the 1-%d range." %
-                         _ext.BLOSC_MAX_TYPESIZE)
+                         blosc.MAX_TYPESIZE)
 
 
 def _check_bytesobj(bytesobj):
@@ -261,9 +262,9 @@ def _check_bytesobj(bytesobj):
 
 
 def _check_input_length(input_name, input_len):
-    if input_len > _ext.BLOSC_MAX_BUFFERSIZE:
+    if input_len > blosc.MAX_BUFFERSIZE:
         raise ValueError("%s cannot be larger than %d bytes" %
-                         (input_name, _ext.BLOSC_MAX_BUFFERSIZE))
+                         (input_name, blosc.MAX_BUFFERSIZE))
 
 
 def _check_address(address):
@@ -271,23 +272,25 @@ def _check_address(address):
         raise TypeError("only int or long objects are supported as address")
 
 
-def compress(bytesobj, typesize, clevel=9, shuffle=True, cname='blosclz'):
-    """compress(bytesobj, typesize[, clevel=9, shuffle=True, cname='blosclz']])
+def compress(bytesobj, typesize=8, clevel=9, shuffle=blosc.SHUFFLE,
+             cname='blosclz'):
+    """compress(bytesobj[, typesize=8, clevel=9, shuffle=blosc.SHUFFLE, cname='blosclz']])
 
     Compress bytesobj, with a given type size.
 
     Parameters
     ----------
-    bytesobj : str / bytes
+    bytesobj : bytes-like object (supporting the buffer interface)
         The data to be compressed.
     typesize : int
         The data type size.
     clevel : int (optional)
         The compression level from 0 (no compression) to 9
         (maximum compression).  The default is 9.
-    shuffle : bool (optional)
-        Whether you want to activate the shuffle filter or not.
-        The default is True.
+    shuffle : int (optional)
+        The shuffle filter to be activated.  Allowed values are
+        blosc.NOSHUFFLE, blosc.SHUFFLE and blosc.BITSHUFFLE.  The
+        default is blosc.SHUFFLE.
     cname : string (optional)
         The name of the compressor used internally in Blosc.
         It can be any of the supported by Blosc ('blosclz',
@@ -302,11 +305,12 @@ def compress(bytesobj, typesize, clevel=9, shuffle=True, cname='blosclz'):
     Raises
     ------
     TypeError
-        If bytesobj is not of type bytes or string.
+        If bytesobj doesn't support the buffer interface.
     ValueError
         If bytesobj is too long.
         If typesize is not within the allowed range.
-        if clevel is not not within the allowed range.
+        If clevel is not within the allowed range.
+        If cname is not a valid codec.
 
     Examples
     --------
@@ -320,7 +324,6 @@ def compress(bytesobj, typesize, clevel=9, shuffle=True, cname='blosclz'):
 
     """
 
-    _check_bytesobj(bytesobj)
     _check_input_length('bytesobj', len(bytesobj))
     _check_typesize(typesize)
     _check_clevel(clevel)
@@ -329,9 +332,9 @@ def compress(bytesobj, typesize, clevel=9, shuffle=True, cname='blosclz'):
     return _ext.compress(bytesobj, typesize, clevel, shuffle, cname)
 
 
-def compress_ptr(address, items, typesize, clevel=9, shuffle=True,
+def compress_ptr(address, items, typesize=8, clevel=9, shuffle=blosc.SHUFFLE,
                  cname='blosclz'):
-    """compress_ptr(address, items, typesize[, clevel=9, shuffle=True, cname='blosclz']])
+    """compress_ptr(address, items[, typesize=8, clevel=9, shuffle=blosc.SHUFFLE, cname='blosclz']])
 
     Compress the data at address with given items and typesize.
 
@@ -346,9 +349,10 @@ def compress_ptr(address, items, typesize, clevel=9, shuffle=True,
     clevel : int (optional)
         The compression level from 0 (no compression) to 9
         (maximum compression).  The default is 9.
-    shuffle : bool (optional)
-        Whether you want to activate the shuffle filter or not.
-        The default is True.
+    shuffle : int (optional)
+        The shuffle filter to be activated.  Allowed values are
+        blosc.NOSHUFFLE, blosc.SHUFFLE and blosc.BITSHUFFLE.  The
+        default is blosc.SHUFFLE.
     cname : string (optional)
         The name of the compressor used internally in Blosc.
         It can be any of the supported by Blosc ('blosclz',
@@ -403,7 +407,7 @@ def compress_ptr(address, items, typesize, clevel=9, shuffle=True,
     >>> d = blosc.decompress(c)
     >>> import struct
     >>> ans = [struct.unpack('d', d[i:i+typesize])[0] \
-            for i in range(0,items*typesize,typesize)]
+            for i in range(0, items*typesize, typesize)]
     >>> data == ans
     True
     """
@@ -420,7 +424,7 @@ def compress_ptr(address, items, typesize, clevel=9, shuffle=True,
     return _ext.compress_ptr(address, length, typesize, clevel, shuffle, cname)
 
 
-def decompress(bytesobj):
+def decompress(bytesobj, as_bytearray=False):
     """decompress(bytesobj)
 
     Decompresses a bytesobj compressed object.
@@ -429,11 +433,16 @@ def decompress(bytesobj):
     ----------
     bytesobj : str / bytes
         The data to be decompressed.
+    as_bytearray : bool, optional
+        If this flag is True then the return type will be a bytearray object
+        instead of a bytesobject.
 
     Returns
     -------
-    out : str / bytes
+    out : str / bytes or bytearray
         The decompressed data in form of a Python str / bytes object.
+        If as_bytearray is True then this will be a bytearray object, otherwise
+        this will be a str/ bytes object.
 
     Raises
     ------
@@ -454,12 +463,13 @@ def decompress(bytesobj):
     True
     >>> b"1"*7 == blosc.decompress(blosc.compress(b"1"*7, 8))
     True
+    >>> type(blosc.decompress(blosc.compress(b"1"*7, 8),
+    ...                                      as_bytearray=True)) is bytearray
+    True
 
     """
 
-    _check_bytesobj(bytesobj)
-
-    return _ext.decompress(bytesobj)
+    return _ext.decompress(bytesobj, as_bytearray)
 
 
 def decompress_ptr(bytesobj, address):
@@ -521,7 +531,7 @@ def decompress_ptr(bytesobj, address):
     >>> nbytes = blosc.decompress_ptr(c, ctypes.addressof(out_array))
     >>> import struct
     >>> ans = [struct.unpack('d', out_array[i:i+typesize])[0] \
-            for i in range(0,items*typesize,typesize)]
+            for i in range(0, items*typesize, typesize)]
     >>> data == ans
     True
     >>> nbytes == items * typesize
@@ -535,8 +545,8 @@ def decompress_ptr(bytesobj, address):
     return _ext.decompress_ptr(bytesobj, address)
 
 
-def pack_array(array, clevel=9, shuffle=True, cname='blosclz'):
-    """pack_array(array[, clevel=9, shuffle=True, cname='blosclz']])
+def pack_array(array, clevel=9, shuffle=blosc.SHUFFLE, cname='blosclz'):
+    """pack_array(array[, clevel=9, shuffle=blosc.SHUFFLE, cname='blosclz']])
 
     Pack (compress) a NumPy array.
 
@@ -547,9 +557,10 @@ def pack_array(array, clevel=9, shuffle=True, cname='blosclz'):
     clevel : int (optional)
         The compression level from 0 (no compression) to 9
         (maximum compression).  The default is 9.
-    shuffle : bool (optional)
-        Whether you want to activate the shuffle filter or not.
-        The default is True.
+    shuffle : int (optional)
+        The shuffle filter to be activated.  Allowed values are
+        blosc.NOSHUFFLE, blosc.SHUFFLE and blosc.BITSHUFFLE.  The
+        default is blosc.SHUFFLE.
     cname : string (optional)
         The name of the compressor used internally in Blosc.
         It can be any of the supported by Blosc ('blosclz',
@@ -638,7 +649,7 @@ def unpack_array(packed_array):
     _check_bytesobj(packed_array)
 
     # First decompress the pickle
-    pickled_array = _ext.decompress(packed_array)
+    pickled_array = _ext.decompress(packed_array, False)
     # ... and unpickle
     array = pickle.loads(pickled_array)
 
@@ -672,7 +683,8 @@ def print_versions():
         processor = "not recognized"
     print("Processor: %s" % processor)
     print("Byte-ordering: %s" % sys.byteorder)
-    print("Detected cores: %s" % blosc.detect_number_of_cores())
+    print("Detected cores: %s" % blosc.ncores)
+    print("Number of threads to use by default: %s" % blosc.nthreads)
     print("-=" * 38)
 
 
